@@ -308,7 +308,7 @@ pub use repeat::{repeat, Repeat};
 pub use repeat_with::{repeat_with, RepeatWith};
 pub use stream::*;
 
-pub mod stream;
+pub(crate) mod stream;
 
 mod empty;
 mod from_fn;
@@ -318,14 +318,14 @@ mod repeat;
 mod repeat_with;
 
 cfg_unstable! {
-    #[doc(hidden)]
-    pub mod double_ended_stream;
+    mod double_ended_stream;
     mod exact_size_stream;
     mod extend;
     mod from_stream;
     mod fused_stream;
     mod interval;
     mod into_stream;
+    mod pending;
     mod product;
     mod successors;
     mod sum;
@@ -337,6 +337,7 @@ cfg_unstable! {
     pub use fused_stream::FusedStream;
     pub use interval::{interval, Interval};
     pub use into_stream::IntoStream;
+    pub use pending::{pending, Pending};
     pub use product::Product;
     pub use stream::Merge;
     pub use successors::{successors, Successors};
